==> ejc-hrmanage-api-3.0.0-20241016.092746-163-sources.jar: com/ejianc/business/hr/vo/salarySystem/SalaryUserDataVO.java <==
package com.ejianc.business.hr.vo.salarySystem;

import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;

/**
 * @Author: jiang
 * @Date: 2023/9/28 11:53
 * 人员基本信息
 **/
public class SalaryUserDataVO {
    private String userCode;//员工编号
    private String employeeCode;//账号
    private String orgCode;//
    private String orgName;//组织
    private String departmentCode;//
    private String departmentName;//部门
    private String name;//姓名
    private String sexName;//性别
    private String card;//身份证
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date birthday;//出生日期
    private Integer age;//年龄
    private String phone;
    private String mobilePhone;
    private String postId;//
    private String postName;//岗位
    private String postDetail;//岗位描述
    private String postCode;//所属岗位序列
    private String educationId;//
    private String educationName;//最高学历
    private String title;//
    private String titleName;//职称
    private String userType;//
    private String userTypeName;//人员类别
    private Integer workYear;//企业司龄
    private String sourceType;//来源类型
    private String sourceTypeSequence;//来源类型排序
    private String levelType;//
    private String levelTypeName;//人才梯队类别
    private String level;//
    private String levelName;//人才梯队级别
    private String url;//人力系统地址
    private String jobLevelCode;//岗级
    private String jobLevelName;
    private String postCodeNew;//职务
    private String postNameNew;
    private String residencyType;//派驻类别
    private String residencyTypeName;//派驻类别
    private String residencyCode;//派驻序列
    private String residencyCodeName;//派驻序列
    private String remark;//备注
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date workStartTime;//到本单位时间
    private Date retireDate;//退休年月
    private String socialDepartmentCode;//社保缴纳单位编码
    private String socialDepartmentName;//社保缴纳单位名称


    public Date getWorkStartTime() {
        return workStartTime;
    }

    public void setWorkStartTime(Date workStartTime) {
        this.workStartTime = workStartTime;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getTitleName() {
        return titleName;
    }

    public void setTitleName(String titleName) {
        this.titleName = titleName;
    }

    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }


    public String getSexName() {
        return sexName;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }

    public String getCard() {
        return card;
    }

    public void setCard(String card) {
        this.card = card;
    }

    public Date getBirthday() {
        return birthday;
    }

    public void setBirthday(Date birthday) {
        this.birthday = birthday;
    }

    public Integer getAge() {
        return age;
    }

    public void setAge(Integer age) {
        this.age = age;
    }

    public String getPostId() {
        return postId;
    }

    public void setPostId(String postId) {
        this.postId = postId;
    }

    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }

    public String getPostDetail() {
        return postDetail;
    }

    public void setPostDetail(String postDetail) {
        this.postDetail = postDetail;
    }

    public String getPostCode() {
        return postCode;
    }

    public void setPostCode(String postCode) {
        this.postCode = postCode;
    }

    public String getEducationId() {
        return educationId;
    }

    public void setEducationId(String educationId) {
        this.educationId = educationId;
    }

    public String getEducationName() {
        return educationName;
    }

    public void setEducationName(String educationName) {
        this.educationName = educationName;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getUserType() {
        return userType;
    }

    public void setUserType(String userType) {
        this.userType = userType;
    }

    public String getUserTypeName() {
        return userTypeName;
    }

    public void setUserTypeName(String userTypeName) {
        this.userTypeName = userTypeName;
    }

    public Integer getWorkYear() {
        return workYear;
    }

    public void setWorkYear(Integer workYear) {
        this.workYear = workYear;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public String getLevelType() {
        return levelType;
    }

    public void setLevelType(String levelType) {
        this.levelType = levelType;
    }

    public String getLevelTypeName() {
        return levelTypeName;
    }

    public void setLevelTypeName(String levelTypeName) {
        this.levelTypeName = levelTypeName;
    }

    public String getLevel() {
        return level;
    }

    public void setLevel(String level) {
        this.level = level;
    }

    public String getLevelName() {
        return levelName;
    }

    public void setLevelName(String levelName) {
        this.levelName = levelName;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getJobLevelCode() {
        return jobLevelCode;
    }

    public void setJobLevelCode(String jobLevelCode) {
        this.jobLevelCode = jobLevelCode;
    }

    public String getJobLevelName() {
        return jobLevelName;
    }

    public void setJobLevelName(String jobLevelName) {
        this.jobLevelName = jobLevelName;
    }

    public String getPostCodeNew() {
        return postCodeNew;
    }

    public void setPostCodeNew(String postCodeNew) {
        this.postCodeNew = postCodeNew;
    }

    public String getPostNameNew() {
        return postNameNew;
    }

    public void setPostNameNew(String postNameNew) {
        this.postNameNew = postNameNew;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getMobilePhone() {
        return mobilePhone;
    }

    public void setMobilePhone(String mobilePhone) {
        this.mobilePhone = mobilePhone;
    }

    public String getResidencyType() {
        return residencyType;
    }

    public void setResidencyType(String residencyType) {
        this.residencyType = residencyType;
    }

    public String getResidencyTypeName() {
        return residencyTypeName;
    }

    public void setResidencyTypeName(String residencyTypeName) {
        this.residencyTypeName = residencyTypeName;
    }

    public String getResidencyCode() {
        return residencyCode;
    }

    public void setResidencyCode(String residencyCode) {
        this.residencyCode = residencyCode;
    }

    public String getResidencyCodeName() {
        return residencyCodeName;
    }

    public void setResidencyCodeName(String residencyCodeName) {
        this.residencyCodeName = residencyCodeName;
    }

    public String getSourceTypeSequence() {
        return sourceTypeSequence;
    }

    public void setSourceTypeSequence(String sourceTypeSequence) {
        this.sourceTypeSequence = sourceTypeSequence;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Date getRetireDate() {
        return retireDate;
    }

    public void setRetireDate(Date retireDate) {
        this.retireDate = retireDate;
    }

    public String getSocialDepartmentCode() {
        return socialDepartmentCode;
    }

    public void setSocialDepartmentCode(String socialDepartmentCode) {
        this.socialDepartmentCode = socialDepartmentCode;
    }

    public String getSocialDepartmentName() {
        return socialDepartmentName;
    }

    public void setSocialDepartmentName(String socialDepartmentName) {
        this.socialDepartmentName = socialDepartmentName;
    }
}

==> ejc-hrmanage-api-3.0.0-20251204.053717-196-sources.jar: com/ejianc/business/hr/vo/salarySystem/SalaryUserDataVO.java <==
package com.ejianc.business.hr.vo.salarySystem;

import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;

/**
 * @Author: jiang
 * @Date: 2023/9/28 11:53
 * 人员基本信息
 **/
public class SalaryUserDataVO {
    private String userCode;//员工编号
    private String employeeCode;//账号
    private String orgCode;//
    private String orgName;//组织
    private String departmentCode;//
    private String departmentName;//部门
    private String name;//姓名
    private String sexName;//性别
    private String card;//身份证
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date birthday;//出生日期
    private Integer age;//年龄
    private String phone;
    private String mobilePhone;
    private String postId;//
    private String postName;//岗位
    private String postDetail;//岗位描述
    private String postCode;//所属岗位序列
    private String educationId;//
    private String educationName;//最高学历
    private String title;//
    private String titleName;//职称
    private String userType;//
    private String userTypeName;//人员类别
    private Integer workYear;//企业司龄
    private String sourceType;//来源类型
    private String sourceTypeSequence;//来源类型排序
    private String levelType;//
    private String levelTypeName;//人才梯队类别
    private String level;//
    private String levelName;//人才梯队级别
    private String url;//人力系统地址
    private String jobLevelCode;//岗级
    private String jobLevelName;
    private String postCodeNew;//职务
    private String postNameNew;
    private String residencyType;//派驻类别
    private String residencyTypeName;//派驻类别
    private String residencyCode;//派驻序列
    private String residencyCodeName;//派驻序列
    private String remark;//备注
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date workStartTime;//到本单位时间
    private Date retireDate;//退休年月
    private String socialDepartmentCode;//社保缴纳单位编码
    private String socialDepartmentName;//社保缴纳单位名称
    private String canWorkOut;//能否派驻

    public String getCanWorkOut() {
        return canWorkOut;
    }

    public void setCanWorkOut(String canWorkOut) {
        this.canWorkOut = canWorkOut;
    }

    public Date getWorkStartTime() {
        return workStartTime;
    }

    public void setWorkStartTime(Date workStartTime) {
        this.workStartTime = workStartTime;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getTitleName() {
        return titleName;
    }

    public void setTitleName(String titleName) {
        this.titleName = titleName;
    }

    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }


    public String getSexName() {
        return sexName;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }

    public String getCard() {
        return card;
    }

    public void setCard(String card) {
        this.card = card;
    }

    public Date getBirthday() {
        return birthday;
    }

    public void setBirthday(Date birthday) {
        this.birthday = birthday;
    }

    public Integer getAge() {
        return age;
    }

    public void setAge(Integer age) {
        this.age = age;
    }

    public String getPostId() {
        return postId;
    }

    public void setPostId(String postId) {
        this.postId = postId;
    }

    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }

    public String getPostDetail() {
        return postDetail;
    }

    public void setPostDetail(String postDetail) {
        this.postDetail = postDetail;
    }

    public String getPostCode() {
        return postCode;
    }

    public void setPostCode(String postCode) {
        this.postCode = postCode;
    }

    public String getEducationId() {
        return educationId;
    }

    public void setEducationId(String educationId) {
        this.educationId = educationId;
    }

    public String getEducationName() {
        return educationName;
    }

    public void setEducationName(String educationName) {
        this.educationName = educationName;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getUserType() {
        return userType;
    }

    public void setUserType(String userType) {
        this.userType = userType;
    }

    public String getUserTypeName() {
        return userTypeName;
    }

    public void setUserTypeName(String userTypeName) {
        this.userTypeName = userTypeName;
    }

    public Integer getWorkYear() {
        return workYear;
    }

    public void setWorkYear(Integer workYear) {
        this.workYear = workYear;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public String getLevelType() {
        return levelType;
    }

    public void setLevelType(String levelType) {
        this.levelType = levelType;
    }

    public String getLevelTypeName() {
        return levelTypeName;
    }

    public void setLevelTypeName(String levelTypeName) {
        this.levelTypeName = levelTypeName;
    }

    public String getLevel() {
        return level;
    }

    public void setLevel(String level) {
        this.level = level;
    }

    public String getLevelName() {
        return levelName;
    }

    public void setLevelName(String levelName) {
        this.levelName = levelName;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getJobLevelCode() {
        return jobLevelCode;
    }

    public void setJobLevelCode(String jobLevelCode) {
        this.jobLevelCode = jobLevelCode;
    }

    public String getJobLevelName() {
        return jobLevelName;
    }

    public void setJobLevelName(String jobLevelName) {
        this.jobLevelName = jobLevelName;
    }

    public String getPostCodeNew() {
        return postCodeNew;
    }

    public void setPostCodeNew(String postCodeNew) {
        this.postCodeNew = postCodeNew;
    }

    public String getPostNameNew() {
        return postNameNew;
    }

    public void setPostNameNew(String postNameNew) {
        this.postNameNew = postNameNew;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getMobilePhone() {
        return mobilePhone;
    }

    public void setMobilePhone(String mobilePhone) {
        this.mobilePhone = mobilePhone;
    }

    public String getResidencyType() {
        return residencyType;
    }

    public void setResidencyType(String residencyType) {
        this.residencyType = residencyType;
    }

    public String getResidencyTypeName() {
        return residencyTypeName;
    }

    public void setResidencyTypeName(String residencyTypeName) {
        this.residencyTypeName = residencyTypeName;
    }

    public String getResidencyCode() {
        return residencyCode;
    }

    public void setResidencyCode(String residencyCode) {
        this.residencyCode = residencyCode;
    }

    public String getResidencyCodeName() {
        return residencyCodeName;
    }

    public void setResidencyCodeName(String residencyCodeName) {
        this.residencyCodeName = residencyCodeName;
    }

    public String getSourceTypeSequence() {
        return sourceTypeSequence;
    }

    public void setSourceTypeSequence(String sourceTypeSequence) {
        this.sourceTypeSequence = sourceTypeSequence;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Date getRetireDate() {
        return retireDate;
    }

    public void setRetireDate(Date retireDate) {
        this.retireDate = retireDate;
    }

    public String getSocialDepartmentCode() {
        return socialDepartmentCode;
    }

    public void setSocialDepartmentCode(String socialDepartmentCode) {
        this.socialDepartmentCode = socialDepartmentCode;
    }

    public String getSocialDepartmentName() {
        return socialDepartmentName;
    }

    public void setSocialDepartmentName(String socialDepartmentName) {
        this.socialDepartmentName = socialDepartmentName;
    }
}
